==> misfortune-0.1.2.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-6Bb9QEgiTafJpOOqCCw22O
key:                  misfortune-0.1.2.1-6Bb9QEgiTafJpOOqCCw22O
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  7f49bba661c956279af6f8274cbb71c3
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.2.8/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-6Bb9QEgiTafJpOOqCCw22O
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22 directory-1.3.6.2
    filepath-1.4.2.2 knob-0.2.2-HihKqJco8PCGnub0q4CgDJ
    random-1.2.1.2-3dTxaovgjM1Bg7GihufWfn
    random-fu-0.3.0.1-IShwC48Caaa5FlPEkUEgZ7 text-1.2.5.0
    utf8-string-1.0.2-AaPuiI83MyhDGzjGdO2RZO
    vector-0.13.1.0-7kspXIhsfaQEZQW3lsFmcE

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> misfortune-0.1.2.1-66-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-J8dWCxNmaJwIcD0EMCR4ck
key:                  misfortune-0.1.2.1-J8dWCxNmaJwIcD0EMCR4ck
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  2f6d3313cc98810ae0bef0ee4a6cc6e4
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.2.8/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-J8dWCxNmaJwIcD0EMCR4ck
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22 directory-1.3.6.2
    filepath-1.4.2.2 knob-0.2.2-HihKqJco8PCGnub0q4CgDJ
    random-1.2.1.2-16EsFile9CO8LN79UJ2fx
    random-fu-0.3.0.1-G6bE7uthyk9J17oIvYC3PJ text-1.2.5.0
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-L0sJ9rsFoTeKCVYCfA24Gj

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
